@@ -46,6 +46,9 @@ class Client(metaclass=abc.ABCMeta):
     async def get(self, *args, **kwargs):
         return await self.request(self.session.get, *args, **kwargs)
 
+    async def head(self, *args, **kwargs):
+        return await self.request(self.session.head, *args, **kwargs)
+
     async def patch(self, *args, **kwargs):
         return await self.request(self.session.patch, *args, **kwargs)
 
